==> jc-1.4.0.tar.gz: java/awt/geom/NoninvertibleTransformException.h <==
// public class java.awt.geom.NoninvertibleTransformException

// class file dependencies
// @dep_class 78a894de376d276f java_awt_geom_NoninvertibleTransformException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_geom_NoninvertibleTransformException_H_
#define _JC_java_awt_geom_NoninvertibleTransformException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$sub_refs	_jc_java_awt_geom_NoninvertibleTransformException$sub_refs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs	_jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$refs	_jc_java_awt_geom_NoninvertibleTransformException$refs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$nonrefs	_jc_java_awt_geom_NoninvertibleTransformException$nonrefs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$object	_jc_java_awt_geom_NoninvertibleTransformException$object;

typedef struct _jc_java_awt_geom_NoninvertibleTransformException$fields_struct	_jc_java_awt_geom_NoninvertibleTransformException$fields_struct;
typedef const struct _jc_java_awt_geom_NoninvertibleTransformException$vmethods	_jc_java_awt_geom_NoninvertibleTransformException$vmethods;
typedef const struct _jc_java_awt_geom_NoninvertibleTransformException$vtable	_jc_java_awt_geom_NoninvertibleTransformException$vtable;
typedef const struct _jc_java_awt_geom_NoninvertibleTransformException$vtype	_jc_java_awt_geom_NoninvertibleTransformException$vtype;

// Class fields structure
struct _jc_java_awt_geom_NoninvertibleTransformException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_geom_NoninvertibleTransformException$fields_struct _jc_java_awt_geom_NoninvertibleTransformException$class_fields;

// Constructors
extern void _jc_java_awt_geom_NoninvertibleTransformException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_geom_NoninvertibleTransformException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_geom_NoninvertibleTransformException$vmethods {
};

// Vtable
struct _jc_java_awt_geom_NoninvertibleTransformException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_geom_NoninvertibleTransformException$vmethods	java_awt_geom_NoninvertibleTransformException;
};

// Vtype
struct _jc_java_awt_geom_NoninvertibleTransformException$vtype {
	_jc_type			type;
	_jc_java_awt_geom_NoninvertibleTransformException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_NoninvertibleTransformException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_NoninvertibleTransformException$refs {
    _jc_java_awt_geom_NoninvertibleTransformException$sub_refs	java_awt_geom_NoninvertibleTransformException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_NoninvertibleTransformException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs	java_awt_geom_NoninvertibleTransformException;
};

// Object instance structure
struct _jc_java_awt_geom_NoninvertibleTransformException$object {
	_jc_java_awt_geom_NoninvertibleTransformException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_NoninvertibleTransformException$vtype	*vtype;
	_jc_java_awt_geom_NoninvertibleTransformException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_NoninvertibleTransformException$vtype _jc_java_awt_geom_NoninvertibleTransformException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_NoninvertibleTransformException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_NoninvertibleTransformException$class_object;

#endif	/* _JC_java_awt_geom_NoninvertibleTransformException_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/NoninvertibleTransformException.h <==
// public class java.awt.geom.NoninvertibleTransformException

// class file dependencies
// @dep_class 78a894de376d276f java_awt_geom_NoninvertibleTransformException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_geom_NoninvertibleTransformException_H_
#define _JC_java_awt_geom_NoninvertibleTransformException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$sub_refs	_jc_java_awt_geom_NoninvertibleTransformException$sub_refs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs	_jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$refs	_jc_java_awt_geom_NoninvertibleTransformException$refs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$nonrefs	_jc_java_awt_geom_NoninvertibleTransformException$nonrefs;
typedef struct _jc_java_awt_geom_NoninvertibleTransformException$object	_jc_java_awt_geom_NoninvertibleTransformException$object;

typedef struct _jc_java_awt_geom_NoninvertibleTransformException$fields_struct	_jc_java_awt_geom_NoninvertibleTransformException$fields_struct;
typedef const struct _jc_java_awt_geom_NoninvertibleTransformException$vmethods	_jc_java_awt_geom_NoninvertibleTransformException$vmethods;
typedef const struct _jc_java_awt_geom_NoninvertibleTransformException$vtable	_jc_java_awt_geom_NoninvertibleTransformException$vtable;
typedef const struct _jc_java_awt_geom_NoninvertibleTransformException$vtype	_jc_java_awt_geom_NoninvertibleTransformException$vtype;

// Class fields structure
struct _jc_java_awt_geom_NoninvertibleTransformException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_geom_NoninvertibleTransformException$fields_struct _jc_java_awt_geom_NoninvertibleTransformException$class_fields;

// Constructors
extern void _jc_java_awt_geom_NoninvertibleTransformException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_geom_NoninvertibleTransformException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_geom_NoninvertibleTransformException$vmethods {
};

// Vtable
struct _jc_java_awt_geom_NoninvertibleTransformException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_geom_NoninvertibleTransformException$vmethods	java_awt_geom_NoninvertibleTransformException;
};

// Vtype
struct _jc_java_awt_geom_NoninvertibleTransformException$vtype {
	_jc_type			type;
	_jc_java_awt_geom_NoninvertibleTransformException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_NoninvertibleTransformException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_NoninvertibleTransformException$refs {
    _jc_java_awt_geom_NoninvertibleTransformException$sub_refs	java_awt_geom_NoninvertibleTransformException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_NoninvertibleTransformException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_geom_NoninvertibleTransformException$sub_nonrefs	java_awt_geom_NoninvertibleTransformException;
};

// Object instance structure
struct _jc_java_awt_geom_NoninvertibleTransformException$object {
	_jc_java_awt_geom_NoninvertibleTransformException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_NoninvertibleTransformException$vtype	*vtype;
	_jc_java_awt_geom_NoninvertibleTransformException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_NoninvertibleTransformException$vtype _jc_java_awt_geom_NoninvertibleTransformException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_NoninvertibleTransformException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_NoninvertibleTransformException$class_object;

#endif	/* _JC_java_awt_geom_NoninvertibleTransformException_H_ */
